@@ -5,8 +5,8 @@ import typer
 from rich import print
 # from tqdm import tqdm
 
-from utils import f1
-from video_duration import get_length, get_file_list
+# from utils import f1
+from .video_duration import get_length, get_file_list
 
 app = typer.Typer()
 
